@@ -9,7 +9,8 @@ import unittest
 
 class TestNine(unittest.TestCase):
     def test_import(self):
-        from nine import (IS_PYTHON2, str, basestring, native_str,
+        from nine import (
+            IS_PYTHON2, str, basestring, native_str,
             integer_types, class_types, range, range_list, reraise,
             iterkeys, itervalues, iteritems, map, zip, filter, input,
             implements_iterator, implements_to_string, implements_repr, nine,
